@@ -1,51 +1,37 @@
+from __future__ import annotations
+
 from io import TextIOWrapper
+from typing import Optional
+
 import click
 
 from chia import __version__
+from chia.cmds.beta import beta_cmd
 from chia.cmds.configure import configure_cmd
-from chia.cmds.farm import farm_cmd
 from chia.cmds.data import data_cmd
+from chia.cmds.db import db_cmd
+from chia.cmds.farm import farm_cmd
 from chia.cmds.init import init_cmd
 from chia.cmds.keys import keys_cmd
 from chia.cmds.netspace import netspace_cmd
 from chia.cmds.passphrase import passphrase_cmd
+from chia.cmds.peer import peer_cmd
+from chia.cmds.plotnft import plotnft_cmd
 from chia.cmds.plots import plots_cmd
+from chia.cmds.plotters import plotters_cmd
 from chia.cmds.rpc import rpc_cmd
 from chia.cmds.show import show_cmd
 from chia.cmds.start import start_cmd
 from chia.cmds.stop import stop_cmd
 from chia.cmds.wallet import wallet_cmd
-from chia.cmds.plotnft import plotnft_cmd
-from chia.cmds.plotters import plotters_cmd
-from chia.cmds.db import db_cmd
 from chia.util.default_root import DEFAULT_KEYS_ROOT_PATH, DEFAULT_ROOT_PATH
 from chia.util.errors import KeychainCurrentPassphraseIsInvalid
-from chia.util.keychain import (
-    Keychain,
-    set_keys_root_path,
-)
+from chia.util.keychain import Keychain, set_keys_root_path
 from chia.util.ssl_check import check_ssl
-from typing import Optional
 
 CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
 
 
-def monkey_patch_click() -> None:
-    # this hacks around what seems to be an incompatibility between the python from `pyinstaller`
-    # and `click`
-    #
-    # Not 100% sure on the details, but it seems that `click` performs a check on start-up
-    # that `codecs.lookup(locale.getpreferredencoding()).name != 'ascii'`, and refuses to start
-    # if it's not. The python that comes with `pyinstaller` fails this check.
-    #
-    # This will probably cause problems with the command-line tools that use parameters that
-    # are not strict ascii. The real fix is likely with the `pyinstaller` python.
-
-    import click.core
-
-    click.core._verify_python3_env = lambda *args, **kwargs: 0  # type: ignore[attr-defined]
-
-
 @click.group(
     help=f"\n  Manage chia blockchain infrastructure ({__version__})\n",
     epilog="Try 'chia start node', 'chia netspace -d 192', or 'chia show -s'",
@@ -56,24 +42,17 @@ def monkey_patch_click() -> None:
     "--keys-root-path", default=DEFAULT_KEYS_ROOT_PATH, help="Keyring file root", type=click.Path(), show_default=True
 )
 @click.option("--passphrase-file", type=click.File("r"), help="File or descriptor to read the keyring passphrase from")
-@click.option(
-    "--force-legacy-keyring-migration/--no-force-legacy-keyring-migration",
-    default=True,
-    help="Force legacy keyring migration. Legacy keyring support will be removed in an upcoming version!",
-)
 @click.pass_context
 def cli(
     ctx: click.Context,
     root_path: str,
     keys_root_path: Optional[str] = None,
     passphrase_file: Optional[TextIOWrapper] = None,
-    force_legacy_keyring_migration: bool = True,
 ) -> None:
     from pathlib import Path
 
     ctx.ensure_object(dict)
     ctx.obj["root_path"] = Path(root_path)
-    ctx.obj["force_legacy_keyring_migration"] = force_legacy_keyring_migration
 
     # keys_root_path and passphrase_file will be None if the passphrase options have been
     # scrubbed from the CLI options
@@ -81,9 +60,10 @@ def cli(
         set_keys_root_path(Path(keys_root_path))
 
     if passphrase_file is not None:
-        from chia.cmds.passphrase_funcs import cache_passphrase, read_passphrase_from_file
         from sys import exit
 
+        from chia.cmds.passphrase_funcs import cache_passphrase, read_passphrase_from_file
+
         try:
             passphrase = read_passphrase_from_file(passphrase_file)
             if Keychain.master_passphrase_is_valid(passphrase):
@@ -118,6 +98,7 @@ def version_cmd() -> None:
 @click.pass_context
 def run_daemon_cmd(ctx: click.Context, wait_for_unlock: bool) -> None:
     import asyncio
+
     from chia.daemon.server import async_run_daemon
     from chia.util.keychain import Keychain
 
@@ -140,12 +121,13 @@ cli.add_command(netspace_cmd)
 cli.add_command(farm_cmd)
 cli.add_command(plotters_cmd)
 cli.add_command(db_cmd)
+cli.add_command(peer_cmd)
 cli.add_command(data_cmd)
 cli.add_command(passphrase_cmd)
+cli.add_command(beta_cmd)
 
 
 def main() -> None:
-    monkey_patch_click()
     cli()  # pylint: disable=no-value-for-parameter
 
 
