@@ -1,5 +1,6 @@
+from __future__ import annotations
+
 import click
-from chia.util.keychain import supports_keyring_passphrase
 
 
 @click.command("init", short_help="Create or migrate the configuration")
@@ -37,9 +38,11 @@ def init_cmd(ctx: click.Context, create_certs: str, fix_ssl_permissions: bool, t
       https://github.com/Chia-Network/chia-blockchain/wiki/Farming-on-many-machines
     """
     from pathlib import Path
-    from .init_funcs import init
+
     from chia.cmds.passphrase_funcs import initialize_passphrase
 
+    from .init_funcs import init
+
     set_passphrase = kwargs.get("set_passphrase")
     if set_passphrase:
         initialize_passphrase()
@@ -53,15 +56,9 @@ def init_cmd(ctx: click.Context, create_certs: str, fix_ssl_permissions: bool, t
     )
 
 
-if not supports_keyring_passphrase():
-    from chia.cmds.passphrase_funcs import remove_passphrase_options_from_cmd
-
-    # TODO: Remove once keyring passphrase management is rolled out to all platforms
-    remove_passphrase_options_from_cmd(init_cmd)
-
-
 if __name__ == "__main__":
-    from .init_funcs import chia_init
     from chia.util.default_root import DEFAULT_ROOT_PATH
 
+    from .init_funcs import chia_init
+
     chia_init(DEFAULT_ROOT_PATH)
