@@ -370,11 +370,13 @@ class CoinStore:
         include_spent_coins: bool,
         puzzle_hashes: List[bytes32],
         min_height: uint32 = uint32(0),
+        *,
+        max_items: int = 50000,
     ) -> List[CoinState]:
         if len(puzzle_hashes) == 0:
             return []
 
-        coins = set()
+        coins: Set[CoinState] = set()
         async with self.db_wrapper.reader_no_transaction() as conn:
             for puzzles in chunks(puzzle_hashes, SQLITE_MAX_VARIABLE_NUMBER):
                 puzzle_hashes_db: Tuple[Any, ...]
@@ -387,13 +389,17 @@ class CoinStore:
                     f"coin_parent, amount, timestamp FROM coin_record INDEXED BY coin_puzzle_hash "
                     f'WHERE puzzle_hash in ({"?," * (len(puzzles) - 1)}?) '
                     f"AND (confirmed_index>=? OR spent_index>=?)"
-                    f"{'' if include_spent_coins else 'AND spent_index=0'}",
-                    puzzle_hashes_db + (min_height, min_height),
+                    f"{'' if include_spent_coins else 'AND spent_index=0'}"
+                    " LIMIT ?",
+                    puzzle_hashes_db + (min_height, min_height, max_items - len(coins)),
                 ) as cursor:
                     row: sqlite3.Row
-                    async for row in cursor:
+                    for row in await cursor.fetchall():
                         coins.add(self.row_to_coin_state(row))
 
+                if len(coins) >= max_items:
+                    break
+
         return list(coins)
 
     async def get_coin_records_by_parent_ids(
@@ -433,11 +439,13 @@ class CoinStore:
         include_spent_coins: bool,
         coin_ids: List[bytes32],
         min_height: uint32 = uint32(0),
+        *,
+        max_items: int = 50000,
     ) -> List[CoinState]:
         if len(coin_ids) == 0:
             return []
 
-        coins = set()
+        coins: Set[CoinState] = set()
         async with self.db_wrapper.reader_no_transaction() as conn:
             for ids in chunks(coin_ids, SQLITE_MAX_VARIABLE_NUMBER):
                 coin_ids_db: Tuple[Any, ...]
@@ -449,11 +457,15 @@ class CoinStore:
                     f"SELECT confirmed_index, spent_index, coinbase, puzzle_hash, "
                     f'coin_parent, amount, timestamp FROM coin_record WHERE coin_name in ({"?," * (len(ids) - 1)}?) '
                     f"AND (confirmed_index>=? OR spent_index>=?)"
-                    f"{'' if include_spent_coins else 'AND spent_index=0'}",
-                    coin_ids_db + (min_height, min_height),
+                    f"{'' if include_spent_coins else 'AND spent_index=0'}"
+                    " LIMIT ?",
+                    coin_ids_db + (min_height, min_height, max_items - len(coins)),
                 ) as cursor:
-                    async for row in cursor:
+                    for row in await cursor.fetchall():
                         coins.add(self.row_to_coin_state(row))
+                if len(coins) >= max_items:
+                    break
+
         return list(coins)
 
     async def rollback_to_block(self, block_index: int) -> List[CoinRecord]:
@@ -560,7 +572,7 @@ class CoinStore:
                 name_params = ",".join(["?"] * len(coin_names_chunk))
                 if self.db_wrapper.db_version == 2:
                     ret: Cursor = await conn.execute(
-                        f"UPDATE OR FAIL coin_record INDEXED BY sqlite_autoindex_coin_record_1 "
+                        f"UPDATE coin_record INDEXED BY sqlite_autoindex_coin_record_1 "
                         f"SET spent_index={index} "
                         f"WHERE spent_index=0 "
                         f"AND coin_name IN ({name_params})",
@@ -568,7 +580,7 @@ class CoinStore:
                     )
                 else:
                     ret = await conn.execute(
-                        f"UPDATE OR FAIL coin_record INDEXED BY sqlite_autoindex_coin_record_1 "
+                        f"UPDATE coin_record INDEXED BY sqlite_autoindex_coin_record_1 "
                         f"SET spent=1, spent_index={index} "
                         f"WHERE spent_index=0 "
                         f"AND coin_name IN ({name_params})",
