@@ -1,12 +1,17 @@
+from __future__ import annotations
+
 from dataclasses import dataclass
 from typing import List, Optional, Tuple
 
+from chia_rs import CoinState, RespondToPhUpdates
+
+from chia.full_node.fee_estimate import FeeEstimateGroup
 from chia.types.blockchain_format.coin import Coin
 from chia.types.blockchain_format.program import SerializedProgram
 from chia.types.blockchain_format.sized_bytes import bytes32
 from chia.types.header_block import HeaderBlock
 from chia.types.spend_bundle import SpendBundle
-from chia.util.ints import uint8, uint32, uint128
+from chia.util.ints import uint8, uint32, uint64, uint128
 from chia.util.streamable import Streamable, streamable
 
 """
@@ -15,6 +20,9 @@ Note: When changing this file, also change protocol_message_types.py, and the pr
 """
 
 
+__all__ = ["CoinState", "RespondToPhUpdates"]
+
+
 @streamable
 @dataclass(frozen=True)
 class RequestPuzzleSolution(Streamable):
@@ -178,12 +186,13 @@ class RespondHeaderBlocks(Streamable):
     header_blocks: List[HeaderBlock]
 
 
-@streamable
-@dataclass(frozen=True)
-class CoinState(Streamable):
-    coin: Coin
-    spent_height: Optional[uint32]
-    created_height: Optional[uint32]
+# This class is implemented in Rust
+# @streamable
+# @dataclass(frozen=True)
+# class CoinState(Streamable):
+#    coin: Coin
+#    spent_height: Optional[uint32]
+#    created_height: Optional[uint32]
 
 
 @streamable
@@ -193,12 +202,13 @@ class RegisterForPhUpdates(Streamable):
     min_height: uint32
 
 
-@streamable
-@dataclass(frozen=True)
-class RespondToPhUpdates(Streamable):
-    puzzle_hashes: List[bytes32]
-    min_height: uint32
-    coin_states: List[CoinState]
+# This class is implemented in Rust
+# @streamable
+# @dataclass(frozen=True)
+# class RespondToPhUpdates(Streamable):
+#    puzzle_hashes: List[bytes32]
+#    min_height: uint32
+#    coin_states: List[CoinState]
 
 
 @streamable
@@ -249,3 +259,19 @@ class RequestSESInfo(Streamable):
 class RespondSESInfo(Streamable):
     reward_chain_hash: List[bytes32]
     heights: List[List[uint32]]
+
+
+@streamable
+@dataclass(frozen=True)
+class RequestFeeEstimates(Streamable):
+    """
+    time_targets (List[uint64]): Epoch timestamps in seconds to estimate FeeRates for.
+    """
+
+    time_targets: List[uint64]
+
+
+@streamable
+@dataclass(frozen=True)
+class RespondFeeEstimates(Streamable):
+    estimates: FeeEstimateGroup
