@@ -1,25 +1,30 @@
+from __future__ import annotations
+
 import asyncio
 import math
+import random
 import time
 import traceback
+from logging import Logger
 from random import Random
 from secrets import randbits
-from typing import Dict, Optional, List, Set
+from typing import Any, Dict, List, Optional, Set, Tuple, Union
 
-
-import chia.server.ws_connection as ws
 import dns.asyncresolver
-from chia.protocols import full_node_protocol, introducer_protocol
+
+from chia.protocols.full_node_protocol import RequestPeers, RespondPeers
+from chia.protocols.introducer_protocol import RequestPeersIntroducer, RespondPeersIntroducer
 from chia.protocols.protocol_message_types import ProtocolMessageTypes
 from chia.server.address_manager import AddressManager, ExtendedPeerInfo
-from chia.server.address_manager_store import AddressManagerStore
 from chia.server.address_manager_sqlite_store import create_address_manager_from_db
-from chia.server.outbound_message import NodeType, make_msg
+from chia.server.address_manager_store import AddressManagerStore
+from chia.server.outbound_message import Message, NodeType, make_msg
 from chia.server.peer_store_resolver import PeerStoreResolver
 from chia.server.server import ChiaServer
+from chia.server.ws_connection import WSChiaConnection
 from chia.types.peer_info import PeerInfo, TimestampedPeerInfo
 from chia.util.hash import std_hash
-from chia.util.ints import uint64
+from chia.util.ints import uint16, uint64
 
 MAX_PEERS_RECEIVED_PER_REQUEST = 1000
 MAX_TOTAL_PEERS_RECEIVED = 3000
@@ -40,21 +45,21 @@ class FullNodeDiscovery:
         server: ChiaServer,
         target_outbound_count: int,
         peer_store_resolver: PeerStoreResolver,
-        introducer_info: Optional[Dict],
+        introducer_info: Optional[Dict[str, Any]],
         dns_servers: List[str],
         peer_connect_interval: int,
         selected_network: str,
         default_port: Optional[int],
-        log,
-    ):
+        log: Logger,
+    ) -> None:
         self.server: ChiaServer = server
-        self.message_queue: asyncio.Queue = asyncio.Queue()
         self.is_closed = False
         self.target_outbound_count = target_outbound_count
         self.legacy_peer_db_path = peer_store_resolver.legacy_peer_db_path
         self.legacy_peer_db_migrated = False
         self.peers_file_path = peer_store_resolver.peers_file_path
         self.dns_servers = dns_servers
+        random.shuffle(dns_servers)  # Don't always start with the same DNS server
         if introducer_info is not None:
             self.introducer_info: Optional[PeerInfo] = PeerInfo(
                 introducer_info["host"],
@@ -64,14 +69,14 @@ class FullNodeDiscovery:
             self.introducer_info = None
         self.peer_connect_interval = peer_connect_interval
         self.log = log
-        self.relay_queue: Optional[asyncio.Queue] = None
+        self.relay_queue: Optional[asyncio.Queue[Tuple[TimestampedPeerInfo, int]]] = None
         self.address_manager: Optional[AddressManager] = None
-        self.connection_time_pretest: Dict = {}
-        self.received_count_from_peers: Dict = {}
+        self.connection_time_pretest: Dict[str, Any] = {}
+        self.received_count_from_peers: Dict[str, Any] = {}
         self.lock = asyncio.Lock()
-        self.connect_peers_task: Optional[asyncio.Task] = None
-        self.serialize_task: Optional[asyncio.Task] = None
-        self.cleanup_task: Optional[asyncio.Task] = None
+        self.connect_peers_task: Optional[asyncio.Task[None]] = None
+        self.serialize_task: Optional[asyncio.Task[None]] = None
+        self.cleanup_task: Optional[asyncio.Task[None]] = None
         self.initial_wait: int = 0
         try:
             self.resolver: Optional[dns.asyncresolver.Resolver] = dns.asyncresolver.Resolver()
@@ -79,7 +84,7 @@ class FullNodeDiscovery:
             self.resolver = None
             self.log.exception("Error initializing asyncresolver")
         self.pending_outbound_connections: Set[str] = set()
-        self.pending_tasks: Set[asyncio.Task] = set()
+        self.pending_tasks: Set[asyncio.Task[None]] = set()
         self.default_port: Optional[int] = default_port
         if default_port is None and selected_network in NETWORK_ID_DEFAULT_PORTS:
             self.default_port = NETWORK_ID_DEFAULT_PORTS[selected_network]
@@ -128,17 +133,14 @@ class FullNodeDiscovery:
         if len(self.pending_tasks) > 0:
             await asyncio.wait(self.pending_tasks)
 
-    def cancel_task_safe(self, task: Optional[asyncio.Task]):
+    def cancel_task_safe(self, task: Optional[asyncio.Task[None]]) -> None:
         if task is not None:
             try:
                 task.cancel()
             except Exception as e:
                 self.log.error(f"Error while canceling task.{e} {task}")
 
-    def add_message(self, message, data):
-        self.message_queue.put_nowait((message, data))
-
-    async def on_connect(self, peer: ws.WSChiaConnection):
+    async def on_connect(self, peer: WSChiaConnection) -> None:
         if (
             peer.is_outbound is False
             and peer.peer_server_port is not None
@@ -161,11 +163,11 @@ class FullNodeDiscovery:
             and (self.server._local_type is NodeType.FULL_NODE or self.server._local_type is NodeType.WALLET)
             and self.address_manager is not None
         ):
-            msg = make_msg(ProtocolMessageTypes.request_peers, full_node_protocol.RequestPeers())
+            msg = make_msg(ProtocolMessageTypes.request_peers, RequestPeers())
             await peer.send_message(msg)
 
     # Updates timestamps each time we receive a message for outbound connections.
-    async def update_peer_timestamp_on_message(self, peer: ws.WSChiaConnection):
+    async def update_peer_timestamp_on_message(self, peer: WSChiaConnection) -> None:
         if (
             peer.is_outbound
             and peer.peer_server_port is not None
@@ -184,7 +186,7 @@ class FullNodeDiscovery:
 
     def _num_needed_peers(self) -> int:
         target = self.target_outbound_count
-        outgoing = len(self.server.get_full_node_outgoing_connections())
+        outgoing = len(self.server.get_connections(NodeType.FULL_NODE, outbound=True))
         return max(0, target - outgoing)
 
     """
@@ -193,23 +195,23 @@ class FullNodeDiscovery:
     (https://en.wikipedia.org/wiki/Poisson_distribution)
     """
 
-    def _poisson_next_send(self, now, avg_interval_seconds, random):
+    def _poisson_next_send(self, now: float, avg_interval_seconds: int, random: Random) -> float:
         return now + (
             math.log(random.randrange(1 << 48) * -0.0000000000000035527136788 + 1) * avg_interval_seconds * -1000000.0
             + 0.5
         )
 
-    async def _introducer_client(self):
+    async def _introducer_client(self) -> None:
         if self.introducer_info is None:
             return None
 
-        async def on_connect(peer: ws.WSChiaConnection):
-            msg = make_msg(ProtocolMessageTypes.request_peers_introducer, introducer_protocol.RequestPeersIntroducer())
+        async def on_connect(peer: WSChiaConnection) -> None:
+            msg = make_msg(ProtocolMessageTypes.request_peers_introducer, RequestPeersIntroducer())
             await peer.send_message(msg)
 
         await self.server.start_client(self.introducer_info, on_connect)
 
-    async def _query_dns(self, dns_address):
+    async def _query_dns(self, dns_address: str) -> None:
         try:
             if self.default_port is None:
                 self.log.error(
@@ -217,7 +219,7 @@ class FullNodeDiscovery:
                 )
                 return
             if self.resolver is None:
-                self.log.warn("Skipping DNS query: asyncresolver not initialized.")
+                self.log.warning("Skipping DNS query: asyncresolver not initialized.")
                 return
             for rdtype in ["A", "AAAA"]:
                 peers: List[TimestampedPeerInfo] = []
@@ -226,17 +228,17 @@ class FullNodeDiscovery:
                     peers.append(
                         TimestampedPeerInfo(
                             ip.to_text(),
-                            self.default_port,
-                            0,
+                            uint16(self.default_port),
+                            uint64(0),
                         )
                     )
                 self.log.info(f"Received {len(peers)} peers from DNS seeder, using rdtype = {rdtype}.")
                 if len(peers) > 0:
-                    await self._respond_peers_common(full_node_protocol.RespondPeers(peers), None, False)
+                    await self._respond_peers_common(RespondPeers(peers), None, False)
         except Exception as e:
-            self.log.warn(f"querying DNS introducer failed: {e}")
+            self.log.warning(f"querying DNS introducer failed: {e}")
 
-    async def on_connect_callback(self, peer: ws.WSChiaConnection):
+    async def on_connect_callback(self, peer: WSChiaConnection) -> None:
         if self.server.on_connect is not None:
             await self.server.on_connect(peer)
         else:
@@ -268,14 +270,15 @@ class FullNodeDiscovery:
             self.log.error(f"Exception in create outbound connections: {e}")
             self.log.error(f"Traceback: {traceback.format_exc()}")
 
-    async def _connect_to_peers(self, random) -> None:
+    async def _connect_to_peers(self, random: Random) -> None:
         next_feeler = self._poisson_next_send(time.time() * 1000 * 1000, 240, random)
         retry_introducers = False
-        introducer_attempts: int = 0
         dns_server_index: int = 0
+        tried_all_dns_servers: bool = False
         local_peerinfo: Optional[PeerInfo] = await self.server.get_peer_info()
         last_timestamp_local_info: uint64 = uint64(int(time.time()))
         last_collision_timestamp = 0
+
         if self.initial_wait > 0:
             await asyncio.sleep(self.initial_wait)
 
@@ -291,13 +294,15 @@ class FullNodeDiscovery:
                         await asyncio.sleep(introducer_backoff)
                     except asyncio.CancelledError:
                         return None
-                    # Run dual between DNS servers and introducers. One time query DNS server,
-                    # next two times query the introducer.
-                    if introducer_attempts % 3 == 0 and len(self.dns_servers) > 0:
+                    # Alternate between DNS servers and introducers.
+                    # First try all the DNS servers in the list once. Then try the introducers once.
+                    if len(self.dns_servers) > 0 and not tried_all_dns_servers:
                         dns_address = self.dns_servers[dns_server_index]
                         dns_server_index = (dns_server_index + 1) % len(self.dns_servers)
+                        tried_all_dns_servers = dns_server_index == 0
                         await self._query_dns(dns_address)
                     else:
+                        tried_all_dns_servers = False
                         await self._introducer_client()
                         # there's some delay between receiving the peers from the
                         # introducer until they get incorporated to prevent this
@@ -309,7 +314,6 @@ class FullNodeDiscovery:
                             return None
 
                     retry_introducers = False
-                    introducer_attempts += 1
                     # keep doubling the introducer delay until we reach 5
                     # minutes
                     if introducer_backoff < 300:
@@ -320,7 +324,7 @@ class FullNodeDiscovery:
 
                 # Only connect out to one peer per network group (/16 for IPv4).
                 groups = set()
-                full_node_connected = self.server.get_full_node_outgoing_connections()
+                full_node_connected = self.server.get_connections(NodeType.FULL_NODE, outbound=True)
                 connected = [c.get_peer_info() for c in full_node_connected]
                 connected = [c for c in connected if c is not None]
                 for conn in full_node_connected:
@@ -434,7 +438,7 @@ class FullNodeDiscovery:
                 self.log.error(f"Exception in create outbound connections: {e}")
                 self.log.error(f"Traceback: {traceback.format_exc()}")
 
-    async def _periodically_serialize(self, random: Random):
+    async def _periodically_serialize(self, random: Random) -> None:
         while not self.is_closed:
             if self.address_manager is None:
                 await asyncio.sleep(10)
@@ -456,14 +460,16 @@ class FullNodeDiscovery:
             await asyncio.sleep(cleanup_interval)
 
             # Perform the cleanup only if we have at least 3 connections.
-            full_node_connected = self.server.get_full_node_connections()
+            full_node_connected = self.server.get_connections(NodeType.FULL_NODE)
             connected = [c.get_peer_info() for c in full_node_connected]
             connected = [c for c in connected if c is not None]
             if self.address_manager is not None and len(connected) >= 3:
                 async with self.address_manager.lock:
                     self.address_manager.cleanup(max_timestamp_difference, max_consecutive_failures)
 
-    async def _respond_peers_common(self, request, peer_src, is_full_node) -> None:
+    async def _respond_peers_common(
+        self, request: Union[RespondPeers, RespondPeersIntroducer], peer_src: Optional[PeerInfo], is_full_node: bool
+    ) -> None:
         # Check if we got the peers from a full node or from the introducer.
         peers_adjusted_timestamp = []
         is_misbehaving = False
@@ -507,22 +513,21 @@ class FullNodeDiscovery:
 
 
 class FullNodePeers(FullNodeDiscovery):
-    self_advertise_task: Optional[asyncio.Task] = None
-    address_relay_task: Optional[asyncio.Task] = None
+    self_advertise_task: Optional[asyncio.Task[None]] = None
+    address_relay_task: Optional[asyncio.Task[None]] = None
 
     def __init__(
         self,
-        server,
-        max_inbound_count,
-        target_outbound_count,
+        server: ChiaServer,
+        target_outbound_count: int,
         peer_store_resolver: PeerStoreResolver,
-        introducer_info,
-        dns_servers,
-        peer_connect_interval,
-        selected_network,
-        default_port,
-        log,
-    ):
+        introducer_info: Dict[str, Any],
+        dns_servers: List[str],
+        peer_connect_interval: int,
+        selected_network: str,
+        default_port: Optional[int],
+        log: Logger,
+    ) -> None:
         super().__init__(
             server,
             target_outbound_count,
@@ -535,22 +540,22 @@ class FullNodePeers(FullNodeDiscovery):
             log,
         )
         self.relay_queue = asyncio.Queue()
-        self.neighbour_known_peers: Dict = {}
+        self.neighbour_known_peers: Dict[PeerInfo, Set[str]] = {}
         self.key = randbits(256)
 
-    async def start(self):
+    async def start(self) -> None:
         await self.migrate_address_manager_if_necessary()
         await self.initialize_address_manager()
         self.self_advertise_task = asyncio.create_task(self._periodically_self_advertise_and_clean_data())
         self.address_relay_task = asyncio.create_task(self._address_relay())
         await self.start_tasks()
 
-    async def close(self):
+    async def close(self) -> None:
         await self._close_common()
         self.cancel_task_safe(self.self_advertise_task)
         self.cancel_task_safe(self.address_relay_task)
 
-    async def _periodically_self_advertise_and_clean_data(self):
+    async def _periodically_self_advertise_and_clean_data(self) -> None:
         while not self.is_closed:
             try:
                 try:
@@ -559,8 +564,8 @@ class FullNodePeers(FullNodeDiscovery):
                     return None
                 # Clean up known nodes for neighbours every 24 hours.
                 async with self.lock:
-                    for neighbour in list(self.neighbour_known_peers.keys()):
-                        self.neighbour_known_peers[neighbour].clear()
+                    for neighbour, known_peers in self.neighbour_known_peers.items():
+                        known_peers.clear()
                 # Self advertise every 24 hours.
                 peer = await self.server.get_peer_info()
                 if peer is None:
@@ -574,7 +579,7 @@ class FullNodePeers(FullNodeDiscovery):
                 ]
                 msg = make_msg(
                     ProtocolMessageTypes.respond_peers,
-                    full_node_protocol.RespondPeers(timestamped_peer),
+                    RespondPeers(timestamped_peer),
                 )
                 await self.server.send_to_all([msg], NodeType.FULL_NODE)
 
@@ -585,16 +590,15 @@ class FullNodePeers(FullNodeDiscovery):
                 self.log.error(f"Exception in self advertise: {e}")
                 self.log.error(f"Traceback: {traceback.format_exc()}")
 
-    async def add_peers_neighbour(self, peers, neighbour_info):
-        neighbour_data = (neighbour_info.host, neighbour_info.port)
+    async def add_peers_neighbour(self, peers: List[TimestampedPeerInfo], neighbour_info: PeerInfo) -> None:
         async with self.lock:
             for peer in peers:
-                if neighbour_data not in self.neighbour_known_peers:
-                    self.neighbour_known_peers[neighbour_data] = set()
-                if peer.host not in self.neighbour_known_peers[neighbour_data]:
-                    self.neighbour_known_peers[neighbour_data].add(peer.host)
+                if neighbour_info not in self.neighbour_known_peers:
+                    self.neighbour_known_peers[neighbour_info] = set()
+                if peer.host not in self.neighbour_known_peers[neighbour_info]:
+                    self.neighbour_known_peers[neighbour_info].add(peer.host)
 
-    async def request_peers(self, peer_info: PeerInfo):
+    async def request_peers(self, peer_info: PeerInfo) -> Optional[Message]:
         try:
 
             # Prevent a fingerprint attack: do not send peers to inbound connections.
@@ -610,17 +614,22 @@ class FullNodePeers(FullNodeDiscovery):
 
             msg = make_msg(
                 ProtocolMessageTypes.respond_peers,
-                full_node_protocol.RespondPeers(peers),
+                RespondPeers(peers),
             )
 
             return msg
         except Exception as e:
             self.log.error(f"Request peers exception: {e}")
+            return None
 
-    async def respond_peers(self, request, peer_src, is_full_node):
+    async def respond_peers(
+        self, request: Union[RespondPeers, RespondPeersIntroducer], peer_src: Optional[PeerInfo], is_full_node: bool
+    ) -> None:
         try:
             await self._respond_peers_common(request, peer_src, is_full_node)
             if is_full_node:
+                if peer_src is None:
+                    return
                 await self.add_peers_neighbour(request.peer_list, peer_src)
                 if len(request.peer_list) == 1 and self.relay_queue is not None:
                     peer = request.peer_list[0]
@@ -628,11 +637,13 @@ class FullNodePeers(FullNodeDiscovery):
                         self.relay_queue.put_nowait((peer, 2))
         except Exception as e:
             self.log.error(f"Respond peers exception: {e}. Traceback: {traceback.format_exc()}")
+        return None
 
-    async def _address_relay(self):
+    async def _address_relay(self) -> None:
         while not self.is_closed:
             try:
                 try:
+                    assert self.relay_queue is not None, "FullNodePeers.relay_queue should always exist"
                     relay_peer, num_peers = await self.relay_queue.get()
                 except asyncio.CancelledError:
                     return None
@@ -640,7 +651,7 @@ class FullNodePeers(FullNodeDiscovery):
                 if not relay_peer_info.is_valid():
                     continue
                 # https://en.bitcoin.it/wiki/Satoshi_Client_Node_Discovery#Address_Relay
-                connections = self.server.get_full_node_connections()
+                connections = self.server.get_connections(NodeType.FULL_NODE)
                 hashes = []
                 cur_day = int(time.time()) // (24 * 60 * 60)
                 for connection in connections:
@@ -663,18 +674,20 @@ class FullNodePeers(FullNodeDiscovery):
                     if index >= num_peers:
                         break
                     peer_info = connection.get_peer_info()
-                    pair = (peer_info.host, peer_info.port)
+                    if peer_info is None:
+                        continue
                     async with self.lock:
-                        if pair in self.neighbour_known_peers and relay_peer.host in self.neighbour_known_peers[pair]:
+                        if peer_info not in self.neighbour_known_peers:
+                            self.neighbour_known_peers[peer_info] = set()
+                        known_peers = self.neighbour_known_peers[peer_info]
+                        if relay_peer.host in known_peers:
                             continue
-                        if pair not in self.neighbour_known_peers:
-                            self.neighbour_known_peers[pair] = set()
-                        self.neighbour_known_peers[pair].add(relay_peer.host)
+                        known_peers.add(relay_peer.host)
                     if connection.peer_node_id is None:
                         continue
                     msg = make_msg(
                         ProtocolMessageTypes.respond_peers,
-                        full_node_protocol.RespondPeers([relay_peer]),
+                        RespondPeers([relay_peer]),
                     )
                     await connection.send_message(msg)
             except Exception as e:
@@ -685,15 +698,15 @@ class FullNodePeers(FullNodeDiscovery):
 class WalletPeers(FullNodeDiscovery):
     def __init__(
         self,
-        server,
-        target_outbound_count,
+        server: ChiaServer,
+        target_outbound_count: int,
         peer_store_resolver: PeerStoreResolver,
-        introducer_info,
-        dns_servers,
-        peer_connect_interval,
-        selected_network,
-        default_port,
-        log,
+        introducer_info: Dict[str, Any],
+        dns_servers: List[str],
+        peer_connect_interval: int,
+        selected_network: str,
+        default_port: Optional[int],
+        log: Logger,
     ) -> None:
         super().__init__(
             server,
@@ -718,5 +731,7 @@ class WalletPeers(FullNodeDiscovery):
             return None
         await self._close_common()
 
-    async def respond_peers(self, request, peer_src, is_full_node) -> None:
+    async def respond_peers(
+        self, request: Union[RespondPeers, RespondPeersIntroducer], peer_src: Optional[PeerInfo], is_full_node: bool
+    ) -> None:
         await self._respond_peers_common(request, peer_src, is_full_node)
