@@ -105,6 +105,7 @@ async def setup_full_node(
     config = local_bt.config
     service_config = config["full_node"]
     service_config["database_path"] = db_name
+    service_config["testing"] = True
     service_config["send_uncompact_interval"] = send_uncompact_interval
     service_config["target_uncompact_proofs"] = 30
     service_config["peer_connect_interval"] = 50
@@ -165,6 +166,7 @@ async def setup_wallet_node(
     with TempKeyring(populate=True) as keychain:
         config = local_bt.config
         service_config = config["wallet"]
+        service_config["testing"] = True
         service_config["port"] = 0
         service_config["rpc_port"] = 0
         service_config["initial_num_public_keys"] = initial_num_public_keys
@@ -321,7 +323,9 @@ async def setup_introducer(bt: BlockTools, port: int) -> AsyncGenerator[Service[
 
 async def setup_vdf_client(bt: BlockTools, self_hostname: str, port: int) -> AsyncGenerator[asyncio.Task[Any], None]:
     lock = asyncio.Lock()
-    vdf_task_1 = asyncio.create_task(spawn_process(self_hostname, port, 1, lock, bt.config.get("prefer_ipv6")))
+    vdf_task_1 = asyncio.create_task(
+        spawn_process(self_hostname, port, 1, lock, prefer_ipv6=bt.config.get("prefer_ipv6", False))
+    )
 
     def stop() -> None:
         asyncio.create_task(kill_processes(lock))
@@ -337,9 +341,15 @@ async def setup_vdf_clients(
     bt: BlockTools, self_hostname: str, port: int
 ) -> AsyncGenerator[Tuple[asyncio.Task[Any], asyncio.Task[Any], asyncio.Task[Any]], None]:
     lock = asyncio.Lock()
-    vdf_task_1 = asyncio.create_task(spawn_process(self_hostname, port, 1, lock, bt.config.get("prefer_ipv6")))
-    vdf_task_2 = asyncio.create_task(spawn_process(self_hostname, port, 2, lock, bt.config.get("prefer_ipv6")))
-    vdf_task_3 = asyncio.create_task(spawn_process(self_hostname, port, 3, lock, bt.config.get("prefer_ipv6")))
+    vdf_task_1 = asyncio.create_task(
+        spawn_process(self_hostname, port, 1, lock, prefer_ipv6=bt.config.get("prefer_ipv6", False))
+    )
+    vdf_task_2 = asyncio.create_task(
+        spawn_process(self_hostname, port, 2, lock, prefer_ipv6=bt.config.get("prefer_ipv6", False))
+    )
+    vdf_task_3 = asyncio.create_task(
+        spawn_process(self_hostname, port, 3, lock, prefer_ipv6=bt.config.get("prefer_ipv6", False))
+    )
 
     def stop() -> None:
         asyncio.create_task(kill_processes(lock))
