@@ -1,9 +1,13 @@
+from __future__ import annotations
+
 import asyncio
 import cProfile
 import logging
 import pathlib
+import tracemalloc
+from datetime import datetime
 
-from chia.util.path import mkdir, path_from_root
+from chia.util.path import path_from_root
 
 # to use the profiler, enable it config file, "enable_profiler"
 # the output will be printed to your chia root path, e.g. ~/.chia/mainnet/profile/
@@ -23,7 +27,7 @@ async def profile_task(root_path: pathlib.Path, service: str, log: logging.Logge
 
     profile_dir = path_from_root(root_path, f"profile-{service}")
     log.info("Starting profiler. saving to %s" % profile_dir)
-    mkdir(profile_dir)
+    profile_dir.mkdir(parents=True, exist_ok=True)
 
     counter = 0
 
@@ -39,12 +43,13 @@ async def profile_task(root_path: pathlib.Path, service: str, log: logging.Logge
 
 
 if __name__ == "__main__":
-    import sys
-    import pstats
     import io
-    from colorama import init, Fore, Back, Style
+    import pstats
+    import sys
     from subprocess import check_call
 
+    from colorama import Back, Fore, Style, init
+
     profile_dir = pathlib.Path(sys.argv[1])
     init(strip=False)
 
@@ -80,6 +85,7 @@ if __name__ == "__main__":
                     if (
                         "{method 'poll' of 'select.epoll' objects}" in columns[5]
                         or "method 'control' of 'select.kqueue' objects" in columns[5]
+                        or "method _overlapped.GetQueuedCompletionStatus" in columns[5]
                     ):
                         # cumulative time
                         sleep += float(columns[3])
@@ -151,3 +157,25 @@ profiler.py <profile-directory> <first-slot> <last-slot>
     Analyze a single slot, or a range of time slots, from the profile directory
 """
         )
+
+
+async def mem_profile_task(root_path: pathlib.Path, service: str, log: logging.Logger) -> None:
+
+    profile_dir = path_from_root(root_path, f"memory-profile-{service}") / datetime.now().strftime("%Y-%m-%d_%H:%M:%S")
+    log.info("Starting memory profiler. saving to %s" % profile_dir)
+    profile_dir.mkdir(parents=True, exist_ok=True)
+
+    try:
+        tracemalloc.start(30)
+
+        counter = 0
+
+        while True:
+            # this will throw CancelledError when we're exiting
+            await asyncio.sleep(60)
+            snapshot = tracemalloc.take_snapshot()
+            snapshot.dump(str(profile_dir / f"heap-{counter:05d}.profile"))
+            log.info(f"Heap usage: {tracemalloc.get_traced_memory()[0]/1000000:0.3f} MB profile {counter:05d}")
+            counter += 1
+    finally:
+        tracemalloc.stop()
