@@ -6,11 +6,13 @@ is returned literally.
 """
 
 
+from __future__ import annotations
+
 from chia.types.blockchain_format.program import Program
 
-from .load_clvm import load_clvm
+from .load_clvm import load_clvm_maybe_recompile
 
-MOD = load_clvm("p2_delegated_conditions.clvm")
+MOD = load_clvm_maybe_recompile("p2_delegated_conditions.clvm")
 
 
 def puzzle_for_pk(public_key: Program) -> Program:
