@@ -1,6 +1,8 @@
+from __future__ import annotations
+
 from unittest import TestCase
 
-from chia.types.blockchain_format.program import Program
+from chia.types.blockchain_format.program import INFINITE_COST, Program
 from chia.util.byte_types import hexstr_to_bytes
 from chia.wallet.puzzles.load_clvm import load_clvm
 
@@ -58,7 +60,7 @@ class TestClvmNativeDeserialization(TestCase):
     def test_deserialization_simple_list(self):
         # ("hello" "friend")
         b = hexstr_to_bytes("ff8568656c6c6fff86667269656e6480")
-        cost, output = DESERIALIZE_MOD.run_with_cost([b])
+        cost, output = DESERIALIZE_MOD.run_with_cost(INFINITE_COST, [b])
         print(cost, output)
         prog = Program.to(output)
         assert prog == Program.from_bytes(b)
@@ -68,7 +70,7 @@ class TestClvmNativeDeserialization(TestCase):
         b = hexstr_to_bytes(
             "ff04ffff0affff0bff0280ffff01ffa02cf24dba5fb0a30e26e83b2ac5b9e29e1b161e5c1fa7425e73043362938b98248080ffff05ffff01ff3380ffff05ff05ffff05ffff01ff6480ffff01ff8080808080ffff01ff8e77726f6e672070617373776f72648080"  # noqa
         )  # noqa
-        cost, output = DESERIALIZE_MOD.run_with_cost([b])
+        cost, output = DESERIALIZE_MOD.run_with_cost(INFINITE_COST, [b])
         print(cost, output)
         prog = Program.to(output)
         assert prog == Program.from_bytes(b)
@@ -78,7 +80,7 @@ class TestClvmNativeDeserialization(TestCase):
         b = hexstr_to_bytes(
             "ff9c00f316271c7fc3908a8bef464e3945ef7a253609ffffffffffffffffffb00fffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffa1ff22ea0179500526edb610f148ec0c614155678491902d6000000000000000000180"  # noqa
         )  # noqa
-        cost, output = DESERIALIZE_MOD.run_with_cost([b])
+        cost, output = DESERIALIZE_MOD.run_with_cost(INFINITE_COST, [b])
         print(cost, output)
         prog = Program.to(output)
         assert prog == Program.from_bytes(b)
@@ -86,28 +88,28 @@ class TestClvmNativeDeserialization(TestCase):
     def test_overflow_atoms(self):
         b = hexstr_to_bytes(serialized_atom_overflow(0xFFFFFFFF))
         try:
-            cost, output = DESERIALIZE_MOD.run_with_cost([b])
+            cost, output = DESERIALIZE_MOD.run_with_cost(INFINITE_COST, [b])
         except Exception:
             assert True
         else:
             assert False
         b = hexstr_to_bytes(serialized_atom_overflow(0x3FFFFFFFF))
         try:
-            cost, output = DESERIALIZE_MOD.run_with_cost([b])
+            cost, output = DESERIALIZE_MOD.run_with_cost(INFINITE_COST, [b])
         except Exception:
             assert True
         else:
             assert False
         b = hexstr_to_bytes(serialized_atom_overflow(0xFFFFFFFFFF))
         try:
-            cost, output = DESERIALIZE_MOD.run_with_cost([b])
+            cost, output = DESERIALIZE_MOD.run_with_cost(INFINITE_COST, [b])
         except Exception:
             assert True
         else:
             assert False
         b = hexstr_to_bytes(serialized_atom_overflow(0x1FFFFFFFFFF))
         try:
-            cost, output = DESERIALIZE_MOD.run_with_cost([b])
+            cost, output = DESERIALIZE_MOD.run_with_cost(INFINITE_COST, [b])
         except Exception:
             assert True
         else:
