@@ -1,11 +1,13 @@
+from __future__ import annotations
+
 from typing import List
 
 from blspy import AugSchemeMPL, G2Element, PrivateKey
 
+from chia.simulator.block_tools import test_constants
 from chia.types.coin_spend import CoinSpend
 from chia.util.condition_tools import conditions_by_opcode, conditions_for_solution, pkm_pairs_for_conditions_dict
 from tests.core.make_block_generator import GROUP_ORDER, int_to_public_key
-from tests.block_tools import test_constants
 
 
 class KeyTool(dict):
